@@ -16,8 +16,6 @@ from pygments.formatters.html import HtmlFormatter
 
 from sphinx.highlighting import PygmentsBridge
 
-from util import with_app
-
 
 class MyLexer(RegexLexer):
     name = 'testlexer'
@@ -41,7 +39,6 @@ class ComplainOnUnhighlighted(PygmentsBridge):
         raise AssertionError("should highlight %r" % source)
 
 
-@with_app()
 def test_add_lexer(app, status, warning):
     app.add_lexer('test', MyLexer())
 
@@ -65,7 +62,7 @@ def test_detect_interactive():
 
 def test_lexer_options():
     bridge = PygmentsBridge('html')
-    ret = bridge.highlight_block('//comment', 'php', opts={'startinline' : True})
+    ret = bridge.highlight_block('//comment', 'php', opts={'startinline': True})
     assert '<span class="c1">//comment</span>' in ret
 
 
