@@ -20,8 +20,9 @@ from babel.messages import pofile, mofile
 from six import string_types
 import pytest
 
-from util import tempdir, rootdir, path, assert_re_search, \
-    assert_not_re_search, assert_startswith, assert_node, etree_parse
+from util import (
+    path, assert_re_search, assert_not_re_search, assert_startswith, assert_node, etree_parse
+)
 
 
 sphinx_intl = pytest.mark.sphinx(
@@ -413,6 +414,18 @@ def test_gettext_toctree(app):
         assert expect_msg.id in [m.id for m in actual if m.id]
 
 
+@sphinx_intl
+@pytest.mark.sphinx('gettext')
+@pytest.mark.test_params(shared_result='test_intl_gettext')
+def test_gettext_table(app):
+    app.build()
+    # --- toctree
+    expect = read_po(app.srcdir / 'table.po')
+    actual = read_po(app.outdir / 'table.pot')
+    for expect_msg in [m for m in expect if m.id]:
+        assert expect_msg.id in [m.id for m in actual if m.id]
+
+
 @sphinx_intl
 @pytest.mark.sphinx('gettext')
 @pytest.mark.test_params(shared_result='test_intl_gettext')
@@ -451,6 +464,22 @@ def test_gettext_glossary_term_inconsistencies(app):
         assert expect_msg.id in [m.id for m in actual if m.id]
 
 
+@sphinx_intl
+@pytest.mark.sphinx('gettext')
+@pytest.mark.test_params(shared_result='test_intl_gettext')
+def test_gettext_literalblock(app):
+    app.build()
+    # --- gettext builder always ignores ``only`` directive
+    expect = read_po(app.srcdir / 'literalblock.po')
+    actual = read_po(app.outdir / 'literalblock.pot')
+    for expect_msg in [m for m in expect if m.id]:
+        if len(expect_msg.id.splitlines()) == 1:
+            # compare tranlsations only labels
+            assert expect_msg.id in [m.id for m in actual if m.id]
+        else:
+            pass  # skip code-blocks and literalblocks
+
+
 @sphinx_intl
 @pytest.mark.sphinx('gettext')
 @pytest.mark.test_params(shared_result='test_intl_gettext')
@@ -483,7 +512,8 @@ def test_gettext_dont_rebuild_mo(make_app, app_params, build_mo):
     assert get_number_of_update_targets(app0) == 0
     # When rewriting the timestamp of mo file, the number of documents to be
     # updated will be changed.
-    (app0.srcdir / 'xx' / 'LC_MESSAGES' / 'bom.mo').utime(None)
+    mtime = (app0.srcdir / 'xx' / 'LC_MESSAGES' / 'bom.mo').stat().st_mtime
+    (app0.srcdir / 'xx' / 'LC_MESSAGES' / 'bom.mo').utime((mtime + 5, mtime + 5))
     assert get_number_of_update_targets(app0) == 1
 
     # Because doctree for gettext builder can not be shared with other builders,
@@ -498,7 +528,7 @@ def test_gettext_dont_rebuild_mo(make_app, app_params, build_mo):
     assert get_number_of_update_targets(app) == 0
     # Even if the timestamp of the mo file is updated, the number of documents
     # to be updated is 0. gettext builder does not rebuild because of mo update.
-    (app0.srcdir / 'xx' / 'LC_MESSAGES' / 'bom.mo').utime(None)
+    (app0.srcdir / 'xx' / 'LC_MESSAGES' / 'bom.mo').utime((mtime + 10, mtime + 10))
     assert get_number_of_update_targets(app) == 0
 
 
@@ -559,6 +589,7 @@ def test_html_index_entries(app):
         start_tag = "<%s[^>]*>" % tag
         end_tag = "</%s>" % tag
         return r"%s\s*%s\s*%s" % (start_tag, keyword, end_tag)
+
     def wrap_nest(parenttag, childtag, keyword):
         start_tag1 = "<%s[^>]*>" % parenttag
         start_tag2 = "<%s[^>]*>" % childtag
@@ -651,7 +682,8 @@ def test_html_rebuild_mo(app):
     updated = app.env.update(app.config, app.srcdir, app.doctreedir, app)
     assert len(updated) == 0
 
-    (app.srcdir / 'xx' / 'LC_MESSAGES' / 'bom.mo').utime(None)
+    mtime = (app.srcdir / 'xx' / 'LC_MESSAGES' / 'bom.mo').stat().st_mtime
+    (app.srcdir / 'xx' / 'LC_MESSAGES' / 'bom.mo').utime((mtime + 5, mtime + 5))
     updated = app.env.update(app.config, app.srcdir, app.doctreedir, app)
     assert len(updated) == 1
 
@@ -781,9 +813,9 @@ def test_xml_keep_external_links(app):
         ['http://example.com/external2',
          'http://example.com/external1'])
     assert_elem(
-           para1[1],
-           ['LINK TO', 'THE PYTHON SITE', 'AND', 'THE SPHINX SITE', '.'],
-           ['http://python.org', 'http://sphinx-doc.org'])
+        para1[1],
+        ['LINK TO', 'THE PYTHON SITE', 'AND', 'THE SPHINX SITE', '.'],
+        ['http://python.org', 'http://sphinx-doc.org'])
 
     # multiple references in the same line
     para2 = secs[2].findall('paragraph')
